@@ -21,11 +21,12 @@
 # If not, see <http://www.gnu.org/licenses/>.                             #
 ###########################################################################
 """Convert :term:`BAM` format to :term:`FASTQ` foarmat"""
+import os
+import subprocess
+
 from bioconvert import ConvBase
 from bioconvert.core.decorators import requires
 from bioconvert.core.utils import get_extension
-import subprocess
-import os
 
 
 class BAM2FASTQ(ConvBase):
@@ -146,14 +147,10 @@ class BAM2FASTQ(ConvBase):
 
             # When the input file is not paired and the output file needs to be compressed
             if isPaired == "0":
-                cmd = "samtools fastq {} > {}.{}".format(
-                    self.infile, outbasename, output_ext
-                )
+                cmd = "samtools fastq {} > {}.{}".format(self.infile, outbasename, output_ext)
                 self.execute(cmd)
                 if ext == ".dsrc":
-                    cmd = "{} {}.{} {}.{}.dsrc".format(
-                        compresscmd, outbasename, output_ext, outbasename, output_ext
-                    )
+                    cmd = "{} {}.{} {}.{}.dsrc".format(compresscmd, outbasename, output_ext, outbasename, output_ext)
 
                 else:
                     cmd = "{} {}.{}".format(compresscmd, outbasename, output_ext)
