@@ -23,6 +23,8 @@
 """Network tools to manipulate the graph of conversion"""
 from os import environ
 
+from bioconvert.core.registry import Registry
+
 import colorlog
 
 _log = colorlog.getLogger(__name__)
@@ -31,9 +33,7 @@ _log = colorlog.getLogger(__name__)
 __all__ = ["create_graph", "get_conversions_wrapped", "create_graph_for_cytoscape"]
 
 
-def create_graph(
-    filename, layout="dot", use_singularity=False, color_for_disabled_converter="red"
-):
+def create_graph(filename, layout="dot", use_singularity=False, color_for_disabled_converter="red"):
     """
 
     :param filename: should end in .png or .svg or .dot
@@ -44,13 +44,13 @@ def create_graph(
     see github.com/cokelaer/graphviz4all
 
     """
-    from bioconvert.core.registry import Registry
 
     rr = Registry()
 
     try:
         if filename.endswith(".dot") or use_singularity is True:
             raise Exception()
+        # local import because optional for bioconvert
         from pygraphviz import AGraph
 
         dg = AGraph(directed=True)
@@ -72,9 +72,7 @@ def create_graph(
                     style="filled",
                     url=url.format(b[0].upper()),
                 )
-                dg.add_edge(
-                    a[0], b[0], color="black" if s else color_for_disabled_converter
-                )
+                dg.add_edge(a[0], b[0], color="black" if s else color_for_disabled_converter)
             else:
                 and_node = "_".join(a) + "_and_" + "_".join(b)
 
@@ -119,7 +117,6 @@ def create_graph(
         dg.layout(layout)
         dg.draw(filename)
         dg.write("conversion.dot")
-        print(list(dg.get_node("FASTQ").attr.values()))
 
     except Exception as e:
         _log.error(e)
@@ -128,16 +125,15 @@ strict digraph{
     node [label="\\N"];
 
     """
-        nodes = set([item for items in rr.get_all_conversions() for item in items[0:1]])
-
+        nodes = set([item for items in rr.get_all_conversions() for item in items[0:1][0]])
         for node in nodes:
             dot += '"{}";\n'.format(node)
         for a, b, s in rr.get_all_conversions():
-            dot += '"{}" -> "{}";\n'.format(a, b)
+            dot += '"{}" -> "{}";\n'.format(a[0], b[0])
         dot += "}\n"
 
-        from easydev import TempFile
         from bioconvert import shell
+        from easydev import TempFile
 
         dotfile = TempFile(suffix=".dot")
         with open(dotfile.name, "w") as fout:
@@ -168,7 +164,6 @@ strict digraph{
 
         ext = filename.rsplit(".", 1)[1]
         cmd = "{}dot -T{} {} -o {}".format(dotpath, ext, dotfile.name, filename)
-        print(dotfile.name)
         try:
             shell(cmd)
         except Exception:
@@ -199,8 +194,13 @@ def create_graph_for_cytoscape(all_converter=False):
     graph_nodes = []
     graph_edges = []
     graph = {
-        "data": {"selected": False,},
-        "elements": {"nodes": graph_nodes, "edges": graph_edges,},
+        "data": {
+            "selected": False,
+        },
+        "elements": {
+            "nodes": graph_nodes,
+            "edges": graph_edges,
+        },
     }
     nodes = {}
 
@@ -208,7 +208,12 @@ def create_graph_for_cytoscape(all_converter=False):
         try:
             return nodes[fmt]
         except:
-            ret = {"data": {"id": "n" + str(len(nodes)), "name": fmt,}}
+            ret = {
+                "data": {
+                    "id": "n" + str(len(nodes)),
+                    "name": fmt,
+                }
+            }
             nodes[fmt] = ret
             graph_nodes.append(ret)
             return ret
