@@ -25,8 +25,7 @@ import colorlog
 from Bio import SeqIO
 
 from bioconvert import ConvBase
-from bioconvert.core.decorators import requires
-from bioconvert.core.decorators import compressor
+from bioconvert.core.decorators import compressor, requires
 
 _log = colorlog.getLogger(__name__)
 
@@ -35,7 +34,7 @@ class FASTA2CLUSTAL(ConvBase):
     """
     Converts a sequence alignment from :term:`FASTA` to :term:`CLUSTAL` format
 
-    Methods available are based on squizz [SQUIZZ]_ or biopython [BIOPYTHON]_, 
+    Methods available are based on squizz [SQUIZZ]_ or biopython [BIOPYTHON]_,
     and goalign [GOALIGN]_.
     """
 
@@ -64,12 +63,8 @@ class FASTA2CLUSTAL(ConvBase):
     @requires("squizz")
     @compressor
     def _method_squizz(self, *args, **kwargs):
-        """Convert :term:`FASTA` file in :term:`CLUSTAL` format using squizz tool.
-
-        """
-        cmd = "squizz -c CLUSTAL {infile} > {outfile}".format(
-            infile=self.infile, outfile=self.outfile
-        )
+        """Convert :term:`FASTA` file in :term:`CLUSTAL` format using squizz tool."""
+        cmd = "squizz -c CLUSTAL {infile} > {outfile}".format(infile=self.infile, outfile=self.outfile)
         self.execute(cmd)
 
     @requires("go")
@@ -79,7 +74,5 @@ class FASTA2CLUSTAL(ConvBase):
 
         `goalign documentation <https://github.com/fredericlemoine/goalign>`_"""
         self.install_tool("goalign")
-        cmd = "goalign reformat clustal -i {infile} -o {outfile}".format(
-            infile=self.infile, outfile=self.outfile
-        )
+        cmd = "goalign reformat clustal -i {infile} -o {outfile}".format(infile=self.infile, outfile=self.outfile)
         self.execute(cmd)
