@@ -49,16 +49,14 @@ class GENBANK2EMBL(ConvBase):
 
     @requires("squizz")
     def _method_squizz(self, *args, **kwargs):
-        """Header is less informative than the one obtained with biopython
-        
-        """
+        """Header is less informative than the one obtained with biopython"""
         cmd = "squizz -f genbank -c embl {} > {} ".format(self.infile, self.outfile)
         self.execute(cmd)
 
     @requires(python_library="biopython")
     def _method_biopython(self, *args, **kwargs):
-        """For this method we use the biopython package Bio.SeqIO. 
-        
+        """For this method we use the biopython package Bio.SeqIO.
+
         `Bio.SeqIO Documentation <https://biopython.org/docs/1.76/api/Bio.SeqIO.html>`_"""
         from Bio import SeqIO
 
