@@ -25,8 +25,7 @@ import colorlog
 from Bio import SeqIO
 
 from bioconvert import ConvBase
-from bioconvert.core.decorators import requires
-from bioconvert.core.decorators import compressor
+from bioconvert.core.decorators import compressor, requires
 
 _log = colorlog.getLogger(__name__)
 
@@ -67,10 +66,6 @@ class PHYLIP2CLUSTAL(ConvBase):
     @requires("squizz")
     @compressor
     def _method_squizz(self, *args, **kwargs):
-        """Convert :term:`PHYLIP` interleaved file in :term:`CLUSTAL` format using squizz tool.
-
-        """
-        cmd = "squizz -c CLUSTAL {infile} > {outfile}".format(
-            infile=self.infile, outfile=self.outfile
-        )
+        """Convert :term:`PHYLIP` interleaved file in :term:`CLUSTAL` format using squizz tool."""
+        cmd = "squizz -c CLUSTAL {infile} > {outfile}".format(infile=self.infile, outfile=self.outfile)
         self.execute(cmd)
